.. image:: https://git.gfz-potsdam.de/EnMAP/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp/badges/main/pipeline.svg
        :target: https://git.gfz-potsdam.de/EnMAP/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp/commits/main
.. image:: https://img.shields.io/pypi/v/enpt_enmapboxapp.svg
        :target: https://pypi.python.org/pypi/enpt_enmapboxapp
.. image:: https://img.shields.io/conda/vn/conda-forge/enpt_enmapboxapp.svg
        :target: https://anaconda.org/conda-forge/enpt_enmapboxapp
.. image:: https://git.gfz-potsdam.de/EnMAP/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp/badges/main/coverage.svg
        :target: coverage_
.. image:: https://img.shields.io/static/v1?label=Documentation&message=GitLab%20Pages&color=orange
        :target: https://enmap.git-pages.gfz-potsdam.de/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp/doc/
.. image:: https://img.shields.io/pypi/l/enpt_enmapboxapp.svg
        :target: https://git.gfz-potsdam.de/EnMAP/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp/blob/main/LICENSE
.. image:: https://img.shields.io/pypi/pyversions/enpt_enmapboxapp.svg
        :target: https://img.shields.io/pypi/pyversions/enpt_enmapboxapp.svg
.. image:: https://img.shields.io/pypi/dm/enpt_enmapboxapp.svg
        :target: https://pypi.python.org/pypi/enpt_enmapboxapp


================
enpt_enmapboxapp
================

A QGIS EnMAPBox plugin providing a GUI for the EnMAP processing tools (EnPT).

* Free software: GNU General Public License v3 or later (GPLv3+)
* Documentation: https://enmap.git-pages.gfz-potsdam.de/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp/doc/

See also the latest coverage_ report and the pytest_ HTML report.


How the GUI looks like
----------------------

.. image:: https://git.gfz-potsdam.de/EnMAP/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp/raw/main/docs/images/screenshot_enpt_enmapboxapp_v1.0.0.png
    :width: 918 px
    :height: 673 px
    :scale: 80 %


Credits
-------
This software was developed within the context of the EnMAP project supported by the DLR Space Administration with
funds of the German Federal Ministry of Economic Affairs and Energy (on the basis of a decision by the German
Bundestag: 50 EE 1529) and contributions from DLR, GFZ and OHB System AG.

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _coverage: https://enmap.git-pages.gfz-potsdam.de/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp/coverage/
.. _pytest: https://enmap.git-pages.gfz-potsdam.de/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp/test_reports/report.html
